## Replication file for "How Robust are Compliance Findings? A study synthesis", JEPP 2012
## Replicate results in table 1: Explanatory Factors for Measures of (Non-)Compliance by Qualitative and Quantitative Studies
## created by Mariyana Angelova, for any questions contact Mariyana Angelova at angelova@uni-mannheim.de or mariyana.angelova@gmail.com

# clean working space
ls()
rm(list=ls())


## set working directory to folder with compliance dataset

## set working directory (MAC) e.g.
setwd('~/Dropbox/Compliance Paper/JEPP-Online-Data/Online')

## set working directory (WINDOWS) e.g.
#setwd('~\\Dropbox\\Compliance Paper\\JEPP-Online-Data\\Online')

## load data (MAC)
load('./compliance2012onlineFinal.RData')

## load data (WINDOWS)
#load('.\\compliance2012onlineFinal.RData')

# keep only case studies and quantitative studies
data<-data[data$type.label!='Descriptive',]



## create table 1
	## make factor variables
	data$studyid<-as.factor(data$studyid.label)
	data$ivtheoryneu<-as.factor(data$ivtheoryneu.label)
	data$dvcat<-as.factor(data$dvcat.label)
	data$type<-as.factor(data$type.label)
	
	# create lists for the variables of interst
		listStudyType<-sort(as.character(unique(data$type)))
		listDvType<-sort(as.character(unique(data$dvcat)))
		listTheory<-sort(as.character(unique(data$ivtheoryneu)))
	
	# create empty matrix for table 1
	ncol<-9
	nrow<-length(listTheory)+1
	table1 <- matrix(NA, nrow=nrow, ncol=ncol)
		# assign column and row names to the matrix
		colnames(table1)<-c('Theory','TranspC','InfingC','ApplC','TotalC','TranspQ','InfingQ','ApplQ','TotalQ')
		rownames(table1)<-c(listTheory,"Total")
		# reformat the matrix into a dataframe
		table1<-as.data.frame(table1)
		# add values for the variable Theory
		table1$Theory<-rownames(table1)
		# make a backup of emtpty table1
		table1_backup<-table1
	
	## assign number of studies for analysing a given theory by type of non-compliance/dv (transposition, infringement, application ) and by type of study (quantitative, qualitative)
	
	for(i in 1: length(listStudyType)) {
		for (j in 1: length(listDvType)) {
		
		## create dataset for a specific study type (qual or quant) and dv type (appl, transp, infring)
		info<-data[data$type==listStudyType[i] & data$dvcat==listDvType[j],]
		total<-length(unique(info$studyid))
		## create data with unique studies analysing a given theory
		info<-unique(info[,c('studyid', 'ivtheoryneu')])
		## count number of studies per theory, assign to an object and transform object into data format
		info<-as.data.frame(table(info$ivtheoryneu))
		
		## assign count info to table1
		## append count information to table 1 given theoretical argument
		table1adj<-merge(x=table1, y=info, by.x='Theory', by.y='Var1', all.x=T, all.y=F)
		table1adj$Freq[table1adj$Theory=='Total']<-total

			## For Case Study
		
			if (listStudyType[i]=="Qualitative" & listDvType[j]=='Transposition') {
				table1adj$TranspC<-table1adj$Freq
				} # & transposition
				
			if (listStudyType[i]=="Qualitative" & listDvType[j]=='Infringements') {
				table1adj$InfingC<-table1adj$Freq
				} # &infringements	
				
			if (listStudyType[i]=="Qualitative" & listDvType[j]=='Application') {
				table1adj$ApplC<-table1adj$Freq
				} 	# & application
		
			## For Quantitative Studies
			
			if (listStudyType[i]=="Quantitative" & listDvType[j]=='Transposition') {
				table1adj$TranspQ<-table1adj$Freq
				} # & transposition
				
			if (listStudyType[i]=="Quantitative" & listDvType[j]=='Infringements') {
				table1adj$InfingQ<-table1adj$Freq
				} # &infringements	
				
			if (listStudyType[i]=="Quantitative" & listDvType[j]=='Application') {
				table1adj$ApplQ<-table1adj$Freq
				} 	# & application
		
			# overwrite table1 with newly created table, delete redundant varibale with the counts
			table1adj<-table1adj[,-dim(table1adj)[2]]
			table1<<-table1adj
		} # close j loop which stands fro DV type
		
	} # close i loop which stands for study type
	
	
	## create total counts 
	
	table1$TotalC<-apply(table1[,c('TranspC','InfingC','ApplC')],MARGIN=1,FUN=sum)
	table1$TotalQ<-apply(table1[,c('TranspQ','InfingQ','ApplQ')],MARGIN=1,FUN=sum)
	table1$TotalCQ<-apply(table1[,c('TotalC','TotalQ')],MARGIN=1,FUN=sum)
	## show table 1
	table1
	
	## compare results with table 1
	tabl1Paper<-table1[c(4,13,14,9,12,8,5,6,1,7,3,11,2,10,15),]
	
	## show full table 1
	tabl1Paper
	
	
	
	## show table1 by column
	## case studies
	tabl1Paper[,c('Theory','TranspC')]
	tabl1Paper[,c('Theory','InfingC')]
	tabl1Paper[,c('Theory','ApplC')]
	tabl1Paper[,c('Theory','TotalC')]
	## quantitative studies
	tabl1Paper[,c('Theory','TranspQ')]
	tabl1Paper[,c('Theory','InfingQ')]
	tabl1Paper[,c('Theory','ApplQ')]
	tabl1Paper[,c('Theory','TotalQ')]
	## total for qualitataive and quantitative studies
	tabl1Paper[,c('Theory','TotalCQ')]


