## Replication file for "How Robust are Compliance Findings? A study synthesis", JEPP 2012
## Get results for table 2 (Wilson Confidence Intervals or other Intervals)
## Make Table 2 (Wilson Confidence Intervals or other Intervals)

## created by Mariyana Angelova, for any questions contact Mariyana Angelova at angelova@uni-mannheim.de or mariyana.angelova@gmail.com



## clean working space
rm(list=ls())
## get packages to calculate Wilson Confidence Intervals
library(gregmisc)
library(MKmisc)

## set working directory (MAC)
# set working directory to folder with compliance dataset
setwd('~/Dropbox/Compliance Paper/JEPP-Online-Data/Online')
# set working directory (WINDOWS)
#setwd('~\\Dropbox\\Compliance Paper\\JEPP-Online-Data\\Online')

## load data (MAC)
load('./compliance2012onlineFinal.RData')

## load data (WINDOWS)
#load('.\\compliance2012onlineFinal.RData')

## backupdata
	data_backup<-data

## Make factor variables
	data$studyid<-as.factor(data$studyid.label)
	data$ivtheoryneu<-as.factor(data$ivtheoryneu.label)
	data$dvcat<-as.factor(data$dvcat.label)
	data$type<-as.factor(data$type.label)
	data$theoryeffect<-as.factor(data$theoryeffect.label)

## Prepare data
	##delete descriptive studies, keep qualitative and quantitative studies
	data<-data[data$type!="Descriptive",]
	## make subsamples for method
	data_qualitative<-data[data$type=="Qualitative",]
	data_quantitative<-data[data$type=="Quantitative",]
	## Count postive/negative/unclear effects for each theoretical argument (separate script)
	source("count.effects.total.qual.quant.R")

## Show results for each theoretical argument
	dv_total_final # qualitative and quantitative studies together
	dv_qualitative_final # qualitative only
	dv_quantitative_final # quantitative only


## Calculate Wilson Confidence Intervals
	## use binomCI from package "MKmisc"
	## for more info on the commans 'binomCI' enter ?binomCI in R
	## we use method="wilson", the same results and the graph can be created using other confidence intervals. To calculate other confidence intervals insert "wald",or "agresti-coull", or "jeffreys", "clopper-pearson" instead of "wilson"



	## All Studies

	## show effects
	dv_total_final
	## save total number of effects (negative+positive+unclear)
	N_total <- apply(dv_total_final[,-1],2,sum)
	## save positive effects 
	success_total <- dv_total_final[2,-1]
	## save unclear effects
	unclear<-dv_total_final[3,-1]

	### Calculate Wilson confidence Intervals
	## create an empty list to save results
	result_total = vector("list", length(N_total))
	## paste results in the empty list
		for(i in 1:length(N_total)){ 	
		result_total[[i]] <- binomCI(x=success_total[[i]], n=N_total[[i]], method="wilson")
		}
		names(result_total) <-names(success_total)

	## QUALITATIVE studies
	## show effects
	dv_qualitative_final
	## save total number of effects (negative+positive only, sum of first and second rows)
	N_qual <- apply(dv_qualitative_final[-3,-1],2,sum)
	## save positive effects (second row)
	success_qual <- dv_qualitative_final[2,-1]
	
	### Calculate Wilson confidence Intervals
	## create an emty list to save the results
	result_qual = vector("list", length(N_qual))
	## paste results 
		for(i in 1:length(N_qual)){ 	
		result_qual[[i]] <- binomCI(x=success_qual[[i]], n=N_qual[[i]], method="wilson")
		}
	## name results
	names(result_qual) <-names(success_qual)


	## QUANTITATIVE studies
	
	## show effects
	dv_quantitative_final
	## save total number of effects (negative+positive only)
	N_quant = apply(dv_quantitative_final[-3,-1],2,sum)
	## save positive effects
	success_quant = dv_quantitative_final[2,-1]

	### Calculate Wilson confidence Intervals
	# create an emty list with length N
	result_quant = vector("list", length(N_quant))
	## paste results 
		for(i in 1:length(N_quant)){ 	
		result_quant[[i]] <- binomCI(x=success_quant[[i]], n=N_quant[[i]], method="wilson")
			}
	## name results
	names(result_quant) <-names(success_quant)


## SHOW ALL RESULTS
## show effect counts
dv_qualitative_final
dv_quantitative_final
dv_total_final

## show Wilson cofidence intervals 

result_total # qualitative and quantitative studies together
result_qual # qualitative studies only
result_quant # quantitative studies only



#------------------------------------------
## Make a GRAPH (table 2) to show results
#------------------------------------------

### Set some graph characteristics
	## Determine a color to be used for the Wilson Confidence
	## get list of colors
	listcol<-colors()
	## determine colors for qualitataive and quantitative studies
	ccol_qual<-listcol[198] # grey45 (198)
	ccol_quant<-listcol[24] # black (24)
	## determine the line width
	lwd<-1.2
	## determine length of line separator for the confidence intervals
	sep=0.2

	
	## Graph coordinates
	par(mar=c(6.1,23.1,5.1,4.1)) # determine graph parameters
	##plot an empty graph
	plot(0,0,type="n",bty="n",xlab="",ylab="",xlim=c(0,1),ylim=c(0,length(N_quant)),yaxt="n",
 	main="", cex.main=0.9, cex.lab=0.8, xaxp=c(0,1,10), cex=1.0, cex.axis=0.8)
	##add vertical dasshed line to indicate the H0 treshhold at 0.5
	abline(v=0.5, lty=3, col="darkgrey", lwd=2.5)


#------------------------------------------
# Quantitative
#------------------------------------------

result_quant<-rev(result_quant)
N_quant<-rev(N_quant)
# Quantitative

for(i in c(1,3:length(N_quant))){
	if (N_quant[i]>=4){
		
lines(c(result_quant[[i]]$CI[1],result_quant[[i]]$CI[2]), c(i,i), lwd=lwd, col=ccol_quant)
lines(c(result_quant[[i]]$CI[1],result_quant[[i]]$CI[1]),c(i+sep,i-sep),lwd=lwd,col=ccol_quant)
lines(c(result_quant[[i]]$CI[2],result_quant[[i]]$CI[2]),c(i+sep,i-sep),lwd=lwd,col=ccol_quant)
points(result_quant[[i]]$estimate,i,pch=19,cex=0.7,col=ccol_quant)
		} # close if
} # close for



#------------------------------------------
# Qualitative
#------------------------------------------

	## reverse the order of the results (to plot the first entry in the restuls (total) on the bottom instead on the top)
	result_qual<-rev(result_qual)
	N_qual<-rev(N_qual)

	for(i in 1:length(N_qual)){
	if (N_qual[(i)]>=4){
	## add a line for the confidence interval, with 0.2 higher than the line for the quantitative studies		
	lines(c(result_qual[[i]]$CI[1],result_qual[[i]]$CI[2]), c(i+0.2,i+0.2), lwd=lwd, 	col=ccol_qual, lty=2)

	lines(c(result_qual[[i]]$CI[1],result_qual[[i]]$CI[1]),c(i+0.2+sep,i+0.2-sep),lwd=lwd, col=ccol_qual)
	lines(c(result_qual[[i]]$CI[2],result_qual[[i]]$CI[2]),c(i+0.2+sep,i+0.2-sep),lwd=lwd, col=ccol_qual)
	points(result_qual[[i]]$estimate,i+0.2,pch=17,cex=0.8, col=ccol_qual)
			} # close if
	} # close for


## Save labels for the theoretical arguments in the order they should occur in the graph (bottom to top)
 namelist_final=c(
 "Total",
 "No Appropriate Category",
 "Control Variable",
  "Learning",
  "Positive Public Support",
  "Power (EU)",
"Supranational Monitoring & Enforcement", 
 "National Monitoring & Enforcement",
 "Few Interministerial Coordination Problems",
 "Favourable Culture",
 "Low Complexity of EU Laws",
"Administrative Efficiency",
   "Preference Fit",
   "Goodness of Fit", 
 "Institutional Decision-Making Capacity"
 )
####### Include info for Theoretical Argument, Total, Unclear effects
	## create empty lists
	names<-vector("list", length(N_total))
  	total<-vector("list", length(N_total))
  	unclear_results<-vector("list", length(N_total))
  	qual<-vector("list", length(N_total))
 	quan<-vector("list", length(N_total))
 	total_unclear<-vector("list", length(N_total))	
	## adjust order of the effects
	N_total<-rev(N_total)
	unclear<-rev(unclear)
	success_qual<-rev(success_qual)
	success_quant<-rev(success_quant)
	## save theory labels
	for(i in 1:length(N_total)){
		names[[i]]<- paste(namelist_final[[i]],sep="")
		}		
	## save total number of effects
	for(i in 1:length(N_total)){
		total[[i]]<- paste("  ",N_total[[i]],sep="")
		}		
	## save number of unclear effects
	for(i in 1:length(N_total)){
		unclear_results[[i]]<- paste("  ",unclear[[i]],"   ",sep="")
		}
	## save total number of effects and unclear together
	for(i in 1:length(N_total)){
		total_unclear[[i]]<- paste(N_total[[i]],"(",unclear[[i]],")",sep="")
		}	
	## save positive effects for qualitative studies
	for(i in 1:length(N_qual)){
		qual[[i]]<- paste(success_qual[[i]],"/",N_qual[[i]],sep="")
		}
	## save positive effects for quantitative studies	
	for(i in 1:length(N_quant)){
		quan[[i]]<- paste(success_quant[[i]],"/", N_quant[[i]],sep="")
		}	
	
	## add labels for the theoretical arguments
	for(i in 1:length(N_total)) mtext(names[i],side=2,at=i,las=2,line=18.9, cex=0.75,adj=0)
	## add results for qualitataive studies (positive/(positive+negative))
	for(i in 1:length(N_total)) mtext(qual[i],side=2,at=i,las=2,line=4.7, cex=0.75)
	## add results for quantitative studies (positive/(positive+negative))
	for(i in 1:length(N_total)) mtext(quan[i],side=2,at=i,las=2,line=2.4, cex=0.75)
	## add total number of effects/number of unclear effects
	for(i in 1:length(N_total)) mtext(total_unclear[i],side=2,at=i,las=2,line=-0.2, cex=0.75)


	## Add Title, clarification Note

	mtext(expression(bold("B - Robustness of Results\n")),side=2,at=17.5, las=1, line=-5.7, cex=0.9, adj=0)
	mtext(expression(bold("A - Case Studies (C) & Quantitative Studies (Q)")),side=2,at=18.1, las=2, line=15.8, cex=0.9, adj=0.1)

	mtext("Theoretical Argument",side=2,at=16.5, las=2, line=18.7, cex=0.8, adj=0)
	mtext("C",side=2,at=16.5, las=2, line=4.7, cex=0.8, adj=1.2)
	mtext("Q",side=2,at=16.5, las=2, line=2.7, cex=0.8, adj=1.2)
	mtext("Total",side=2,at=16.5, las=2, line=-0.2, cex=0.8)
	mtext("(Unclear)",side=2,at=16, las=2, line=-0.8, cex=0.8)
	mtext("Note: Part A lists the number of positive effects / sum of positive & negative effects on compliance by theoretical argument. Part B indicates the\n  corresponding observed probability: ",side=2,at=-3.2, las=2, line=17.3, cex=0.7, adj=0.04)

	# Observed probability
	legend(-0.49,-2.95, c("C,","Q,"),col=c(ccol_qual,ccol_quant), pch=c(17,19),xpd=NA, cex=0.7, horiz=TRUE,bty="n")
	mtext("and 95 % Wilson Confidence Intervals: ", side=2,at=-3.54, las=2, line=3.9, cex=0.7, adj=0.04)
	legend(0.28,-2.96,legend=c("C,","Q."),col=c(ccol_qual,ccol_quant), lty=c(2,1),cex=0.68,xpd=NA, bty="n", horiz=TRUE)
	# add line below Theoretical argument
	segments(x0=0,x1=-1.1,y0=15.5,y1=15.5, xpd=NA)
	# add line before total
	segments(x0=0,x1=-1.1,y0=1.5,y1=1.5, xpd=NA)
	# add line after total
	segments(x0=0,x1=-1.1,y0=0.5,y1=0.5, xpd=NA)





