## Replication file for "How Robust are Compliance Findings? A study synthesis", JEPP 2012
# Replicate results in table 3 : Number of studies analyzing (robust) explanatory factors by policy field
# + extended Version of table 3 for all theoretical arguments: online APPENDIX

## created by Mariyana Angelova, for any questions contact Mariyana Angelova at angelova@uni-mannheim.de or mariyana.angelova@gmail.com




# clean working space
ls()
rm(list=ls())


## set working directory to folder with compliance dataset

## set working directory (MAC) e.g.
setwd('~/Dropbox/Compliance Paper/JEPP-Online-Data/Online')

## set working directory (WINDOWS) e.g.
#setwd('~\\Dropbox\\Compliance Paper\\JEPP-Online-Data\\Online')

## load data (MAC)
load('./compliance2012onlineFinal.RData')

## load data (WINDOWS)
#load('.\\compliance2012onlineFinal.RData')

# keep only case studies and quantitative studies
data<-data[data$type.label!='Descriptive',]

	
	## assign exisitng variables to new variables

	## make factor variables
	data$studyid<-as.factor(data$studyid.label)
	data$ivtheoryneu<-as.factor(data$ivtheoryneu.label)
	data$dvcat<-as.factor(data$dvcat.label)
	data$type<-as.factor(data$type.label)


	## retreive info for number of studies per policy field and theoretical argument
	## qualitataive studies
	length(unique(data$studyid[data$agr_fish==1 & data$ivtheoryneu=="Institutional decision-making capacity" & data$type=="Qualitataive"]))
	##quantitataive studies
	length(unique(data$studyid[data$agr_fish==1 & data$ivtheoryneu=="Institutional decision-making capacity" & data$type=="Quantitative"]))
		
	##... for the reamining theoretical arguments paste one of the theoretical arguments in the code from above in the place of "Institutional decision-making capacity": (Good fit,Preferences,Administrative efficiency,Low complexity of EU laws,Favourable culture,Interministerial coordination problems,National monitoring and enforcement,Supranational monitoring and enforcement,Power (EU),Positive public support, Learning,Control variable,No appropriate category)
	## repeat the same approach for each policy field which are saved as dummy variables and can be seen by entering: names(data)




### CREATE TABLE 3

	
	## THEORETICAL ARGUMENTS
		##create lists with theoretical arguments
		listTheory<-sort(as.character(unique(data$ivtheoryneu)))
		##reorganize list with Theories to the occurence in table2 of the paper 
		listTheory<-c(listTheory[5], listTheory[4],listTheory[13],listTheory[1],listTheory[8],listTheory[3],listTheory[6],listTheory[9],listTheory[14],listTheory[12],listTheory[11],listTheory[7],listTheory[2],listTheory[10])		## create theory abbreviations for later
		listTheoryAbb<-c("IDMC","GoF","PREF",'AE',"COMPL","CULT",'COORD','NME','SNME','POW','PS','LEARN','CV','NAC','ALL','CQALL')
	## POLICY FIELDS	
		## create a list with policy fields
		listPolicy<-c('env_cons_health',"agr_fish","energy","labour_social","justice","transport","economy","tax","internal_market","undertakings","services","customs","competition","finance","exterior","eucitizenship","all_no_differentiation")
		## reorganize list with policy fields following the order in table 3 in the paper
		listPolicy<-c(listPolicy[2],listPolicy[9],listPolicy[6],listPolicy[1],listPolicy[11],listPolicy[4],listPolicy[8],listPolicy[3],listPolicy[10],listPolicy[5],listPolicy[13],listPolicy[12],listPolicy[14],listPolicy[7],listPolicy[16],listPolicy[15],listPolicy[17])	
		## create policy field abbreviations for later
		listPolicyAbb<-c("AGRICULTURE","INTERNAL MARKET","TRANSPORT","ENVIRONMENT","SERVICE","LABOUR and SOCIAL","TAXATION","ENERGY","UNDERTAKINGS","JUSTICE","COMPETITION","CUSTOMS","FINANCE","ECONOMY","PEOPLE's EUROPE","EXTERNAL RELATIONS","NO DIFFERENTIATION","Average rates","Total")
				
	
		## create empty matrix for table 3
		ncol<-length(listTheory)+2 # number columns in the table
		nrow<-length(listPolicyAbb) # number of rows in the table
		table3 <- matrix(NA, nrow=nrow, ncol=ncol)
		
		## assign column and row names to the matrix
		colnames(table3)<-c(listTheory,'All',"CQALL")
		rownames(table3)<-c(listPolicy,"Average rates", "Total")
		## reformat the matrix into a dataframe
		table3<-as.data.frame(table3)
		## show empty table3
		table3
		## save empty table for quantitative studies
		empty_matrix<-table3
		## create a variable for policy fields
		table3$policy<-rownames(table3)
	
		
##### QUALITATIVE STUDIES		
		
		## assign number of studies per theory and policy field (QUALITATIVE STUDIES)
	
		for(i in 1: length(listPolicy)) {
			for (j in 1: length(listTheory)) {
			## subsample of qualitative studies analyzing policy filed i (see lis "listPolicy" by inserting e.g listPolicy[1], listPolicy[2]...listPolicy[i]]))
			info<-data[data$type=="Qualitative" & data[, listPolicy[i]]==1,]			## count numbrt of studies for  policy field i and theory j
			res<-length(unique(info$studyid[info$ivtheoryneu==listTheory[j]]))
			## determine the place where the results (res) should be inserted
			## given policy filed i
			policy<-which(table3$policy==listPolicy[i])
			## given theory j
			theory<-which(names(table3)==listTheory[j])
			## insert results in the table
			table3[policy,theory]<-res
			## count total number of qualitative studies for policy field i
			all<-length(unique(info$studyid))
			## insert total number of studies for policy field i in table 3
			table3[policy,"All"]<-all
			
			## count total number of studies given theory i
			total<-length(unique(data$studyid[data$ivtheoryneu==listTheory[j] & data$type=="Qualitative"]))
			## insert total number of studies given theory i
			table3[table3$policy=="Total",theory]<-total
			## open to take the mean number of studies for all policy fields (except all_no_differentiation) and round it
			#avarage<-round(mean(table3[1:16,theory]),2) 
			## open to insert avarage values for each theory
			#table3[table3$policy=="Average rates",theory]<-avarage

			## count total number of (qualitative studies)
			totalAll<-length(unique(data$studyid[data$type=="Qualitative"]))
			## insert total number of qualitative studies
			table3[table3$policy=="Total","All"]<-totalAll

			
		} # close j loop which stands for theory
	} # close i loop which stands for policy fields
	
		## save results in a new object
		table3_Qulitative<-table3
	
	
		## SHOW RESULTS for table 3 for QULITATIVE STUDIES
		table3_Qulitative	

	
### QUANTITATIVE STUDIES
	
	## assign empty matrix to table3
	table3<-empty_matrix
	table3$policy<-rownames(table3)
	
			for(i in 1: length(listPolicy)) {
			for (j in 1: length(listTheory)) {
			## subsample of qualitative studies analyzing policy filed i (see lis "listPolicy" by inserting e.g listPolicy[1], listPolicy[2]...listPolicy[i]]))
			info<-data[data$type=="Quantitative" & data[, listPolicy[i]]==1,]			## count numbrt of studies for  policy field i and theory j
			res<-length(unique(info$studyid[info$ivtheoryneu==listTheory[j]]))
			## determine the place where the results (res) should be inserted
			## given policy filed i
			policy<-which(table3$policy==listPolicy[i])
			## given theory j
			theory<-which(names(table3)==listTheory[j])
			## insert results in the table
			table3[policy,theory]<-res
			## count total number of qualitative studies for policy field i
			all<-length(unique(info$studyid))
			## insert total number of studies for policy field i in table 3
			table3[policy,"All"]<-all
			## count total number of all studies for policy field i
			cqall<-length(unique(data$studyid[data[, listPolicy[i]]==1]))
			## insert tottal number of all studies per policy field i
			table3[policy,"CQALL"]<-cqall
			
			## count total number of studies given theory i
			total<-length(unique(data$studyid[data$ivtheoryneu==listTheory[j] & data$type=="Quantitative"]))
			## insert total number of studies given theory i
			table3[table3$policy=="Total",theory]<-total
			## open to take the mean number of studies for all policy fields (except all_no_differentiation) and round it
			#avarage<-round(mean(table3[1:16,theory]),2) 
			##open to insert avarage values for each theory
			#table3[table3$policy=="Average rates",theory]<-avarage

			## count total number of (qualitative studies)
			totalAll<-length(unique(data$studyid[data$type=="Quantitative"]))
			## insert total number of qualitative studies
			table3[table3$policy=="Total","All"]<-totalAll
			## count total number of studies
			totalCQAll<-length(unique(data$studyid))
			table3[table3$policy=="Total","CQALL"]<-totalCQAll

			
		} # close j loop which stands for theory
	} # close i loop which stands for policy fields
	
	## save results for Quantitative studies in a separate object
	
	table3_Quantitative<-table3
	
	## combine results: APPENDIX
	table3_Quantitative
	table3_Qulitative
	appendix<-cbind(table3_Qulitative, table3_Quantitative)
	## delete redundant policy variables
	del.variables<-which(names(appendix)=="policy")
	appendix<-appendix[,-del.variables]
	## rename theoretical arguments with their corresponding abbreviations and add _C for Qualitataive(Case) Studies and _Q for Quantitative Studies
	qual<-paste(listTheoryAbb,"_C",sep="")
	quant<-paste(listTheoryAbb,"_Q",sep="")
	## paste theory abbreviations 
	names(appendix)<-c(qual,quant[-16],"CQALL")
	## paste policy field abbreviations
	rownames(appendix)<-listPolicyAbb
	## show APPENDIX TABLE
	appendix
	
	
	## short VERSION: Table 3
	## choose Theoretical Arguments: IDMC, GOF, AE, NME, ALL
	rel.theories<-which(names(appendix)=="IDMC_C"| names(appendix)=="GoF_C"| names(appendix)=="AE_C" | names(appendix)=="NME_C"| names(appendix)=="ALL_C" | names(appendix)=="IDMC_Q"| names(appendix)=="GoF_Q" | names(appendix)=="AE_Q" | names(appendix)=="NME_Q"| names(appendix)=="ALL_Q" | names(appendix)=="CQALL")
	## assign results for these theoretical arguements
	table3.paper<-appendix[, rel.theories]	
	## show table 3 from the paper
	table3.paper
	
	

