### Main models for Angelova (2018) Dissertation Chapter 3: Coalition Conflict - a Remedy for Democratic Accountability?
## All analyses, simulations, tables, and figures were created on OS 10.13.6 (High Sierra) using R version 3.5.0 (2018-04-23) and Zelig version Zelig 5.1.6 (note that newer and older versions of Zelig use different syntax)
## ALL RESPONDENTS


### Before running this script run the following R script to get GIP data provided via Gesis: source('./1_replication_file_get_data.R')

## set working directory
setwd("~/Documents/Dissertation/Diss - Replication - Chapter 3")

## clean working space
	rm(list = ls(all = TRUE))

	print(sessionInfo())

## get packages
	library("Zelig")
	library("mlogit")
	library("nnet")
	library("memisc")
	library("stargazer")
	library("xtable")
	library("texreg")
	library("stargazer")
	library("Hmisc")
	library("MASS")

## get gip data
	
	load(file="./gip_data/gip.rda") # this data is created in script ./1_replication_file_get_data.R
	gip.backup<-gip
	dim(gip.backup)
	options(signif.symbols=c("***"=.001,"**"=.01,"*"=.05,"'"=.1))
	
	## run additional variable modifications
	source('./var_modifications.R')
	
	gip$vote_le3_orig<-as.factor(gip$vote_last_election_cducsu_fdp_opp)
	gip$vote_le3<-relevel(gip$vote_le3_orig, ref="opposition")

	  ## keep only respondents from second wave
	gip<-gip[gip$gip2==1,]
	
	
	## select only these who know that FDP and CDU/CSU are gov parties
	gip.know.cducsu.fdp<-gip[ gip$gov_knowledge_fdp==1 & gip$gov_knowledge_cducsu==1,]
	gip.know.cducsu<-gip[gip$gov_knowledge_cducsu==1,]
	gip.know.fdp<-gip[ gip$gov_knowledge_fdp==1,]
	
	dim(gip)

	
	## MAIN ANALYSES
	## ALL RESPONDENTS
	
	
	## SET to all respondents
	
	gip.know.cducsu.fdp<-gip
	gip.know.cducsu<-gip
	gip.know.fdp<-gip
	
	dim(gip.know.cducsu.fdp)
	dim(gip.know.cducsu)
	dim(gip.know.fdp)
	
##======================================================================================================================		
## ANALYSES for TABLE 3.2 (Model 1-4)
##======================================================================================================================		
	
	## Model 1: Government responsibility
	resp<-zelig(gridlock_resp_gov ~ gov_conflict + cducsu_conflict + fdp_conflict + lr_gov_distance+ vote_le_gov+competence_gov_nas_as_0+ lr_self +age_cat + woman + education+ religion_activity+ pol_know_all+family_satisfaction + financial_satisfaction + leisure_satisfaction, model="logit", data= gip.know.cducsu.fdp, cite=F)	; summary(resp)
	
## COMPETENCE Models: Models 2,3,4, Table 3.2 (Chapter 3)
		## Model 2: GOV Competence
		gov_competence<-zelig(competence_gov_nas_as_0 ~ gov_conflict+cducsu_conflict + fdp_conflict+ vote_le_gov +satisfaction_gov + pol_know_all+econ_decline+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction, model="logit", data= gip.know.cducsu.fdp) ;  summary(gov_competence)
       
		## Model 3: CDUCSU Competence
		cducsu_competence<-zelig(competence_cducsu_nas_as_0 ~ gov_conflict +cducsu_conflict+ vote_le3 +satisfaction_gov + pol_know_all+econ_decline+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction, model="logit", data= gip.know.cducsu.fdp) ;  summary(cducsu_competence)
       
		## Model 4: FDP Competence
		fdp_competence<-zelig(competence_fdp_nas_as_0 ~ gov_conflict +fdp_conflict+ vote_le3 +satisfaction_gov + pol_know_all+econ_decline+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction, model="logit", data= gip.know.cducsu.fdp);         summary(fdp_competence)
 
		## save models		
				model1<-resp
        model2<-gov_competence
        model3<-cducsu_competence
        model4<-fdp_competence
        
##======================================================================================================================		
## Show results presented in TABLE 3.2
##======================================================================================================================		
    
    table3.2<-list(model1, model2, model3, model4)
    screenreg(table3.2, digits=3)
    texreg(table3.2, digits=3) 

##======================================================================================================================		
## Figure 3.1: predicted probability of government responsibility for policy failure
##======================================================================================================================		

    ## Get predicted probabilities
    ## specify parameters
    c.min<-min(gip$gov_conflict, na.rm=T); c.max<-max(gip$gov_conflict, na.rm=T); gov.c<-seq(c.min, c.max,length.out=50)
    gov<-1
    
    ## simulations
    mod<-NA; mod<-resp
    modx<-setx(mod, vote_le_gov = gov, gov_conflict= gov.c, woman =0)
    mods<-sim(mod, modx, num=10000)
    
    ## save simulation resutls
    res<-NA; res<-get_qi(mods, xvalue="range")
    res<-as.data.frame(res); names(res)<-1:50
    resp.gov<-res

##======================================================================================================================		
## Plot FIGURE 3.1
##======================================================================================================================		
    
    pdf(file="./robustness checks/graphs/figure3.1_all_respondents.pdf", bg="transparent",width=4.7, height=4.8)
    
    par(mfrow=c(1,1))
    par(mar=c(5,5,4,3))
    plot(y=c(0,0.7), x=c(0,10), type="n", xlab="Perceived Coalition Conflict", ylab="Probability of Gov Responsibility", las=1, main="Coalition Conflict & \n Responsibility for Policy Failure", cex.main=1,xaxt="n", cex.axis=1, cex.lab=1.1) 
    axis(1, at=0:10, labels=0:10, cex.axis=1)		
    lines(x= gov.c,y=apply(resp.gov,2, mean), lwd=2, col="black")
    lines(x= gov.c,y=apply(resp.gov,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
    lines(x= gov.c,y=apply(resp.gov,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
    dev.off()
    
    # control
    cbind(apply(resp.gov,2, mean), gov.c)
    
####+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++		
## Alternative way to get the predicted values	
####+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++		
    
    alt.resp<-glm(gridlock_resp_gov ~ gov_conflict + cducsu_conflict + fdp_conflict + lr_gov_distance+ vote_le_gov+competence_gov_nas_as_0+ lr_self +age_cat + woman + education+ religion_activity+ pol_know_all+family_satisfaction + financial_satisfaction + leisure_satisfaction, family=binomial(link="logit"), data=gip.know.cducsu.fdp)
    summary(alt.resp)
    
    
    ## specify values
    gov.c # coalition conflict
    cducsu.c<-mean(gip.know.cducsu.fdp$cducsu_conflict,na.rm=T) # cducsu conflict
    fdp.c<-mean(gip.know.cducsu.fdp$fdp_conflict, na.rm=T) ## fdp conflict
    lr<-mean(gip.know.cducsu.fdp$lr_gov_distance, na.rm=T) ## lr gov distance
    gov # government voters
    com<-1 # government competence, median(gip$competence_gov_nas_as_0)
    lr.self<-mean(gip.know.cducsu.fdp$lr_self, na.rm=T)
    age<-mean(gip.know.cducsu.fdp$age_cat,na.rm=T)
    woman<-0
    education<-mean(gip.know.cducsu.fdp$education,na.rm=T)
    rel<-median(as.numeric(as.character(gip.know.cducsu.fdp$religion_activity)),na.rm=T)
    rel2<-0
    rel3<-0
    pol.know<-mean(gip.know.cducsu.fdp$pol_know_all,na.rm=T)	
    fam<-mean(gip.know.cducsu.fdp$family_satisfaction,na.rm=T)
    fin<-mean(gip.know.cducsu.fdp$financial_satisfaction,na.rm=T)	
    lei<-mean(gip.know.cducsu.fdp$leisure_satisfaction,na.rm=T)	
    
    ## set X values
    X <- cbind(1, gov.c, cducsu.c, fdp.c, lr,gov,com,lr.self,age, woman, education,rel2, rel3,pol.know, fam, fin, lei )
    ## draw coefficients
    BETA <- mvrnorm(10000,coef(alt.resp),vcov(alt.resp))
    ## get predicted values
    y.star <- BETA %*% t(X)
    ## get probability
    pp <- 1/(1 + exp(-y.star))
    pp<-as.data.frame(pp)
    names(pp)<-1:50
    
  
    ## plot
    pdf(file="./robustness checks/graphs/figure3.1_control_all_respondents.pdf", bg="transparent",width=4.7, height=4.8)
    par(mfrow=c(1,1))
    par(mar=c(5,5,4,3))
    plot(y=c(0,0.7), x=c(0,10), type="n", xlab="Perceived Coalition Conflict", ylab="Probability of Gov Responsibility", las=1, main="Coalition Conflict & \n Responsibility for Policy Failure", cex.main=1,xaxt="n", cex.axis=1, cex.lab=1.1) 
    axis(1, at=0:10, labels=0:10, cex.axis=1)		
    lines(x= gov.c,y=apply(pp,2, mean), lwd=2, col="black")
    lines(x= gov.c,y=apply(pp,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
    lines(x= gov.c,y=apply(pp,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
    
    dev.off()
    
    ## essentially identical
    cbind(apply(resp.gov,2, mean),apply(pp,2, mean), gov.c)
    screenreg(list(resp,alt.resp), digits=3)
    
  ####+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++	
    
  
##======================================================================================================================		
## ANALYSES for TABLE 3.3 - Model 5-9
##======================================================================================================================		
    
##----------------------------------------------------------
## Models 5-7: Government Ratings, economic decline
##----------------------------------------------------------
	
		## Model 5
    gov_rating_economy_s1<-zelig(satisfaction_gov ~ econ_decline+gov_conflict+cducsu_conflict + fdp_conflict + vote_le_gov+ competence_gov_nas_as_0 + age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp); summary(gov_rating_economy_s1) 
		
    ## Model 6
	  gov_rating_economy_s2<-zelig(satisfaction_gov ~ econ_decline*gov_conflict+cducsu_conflict + fdp_conflict + vote_le_gov+ competence_gov_nas_as_0 + age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp); summary(gov_rating_economy_s2)
	  
	  ## Model 7
    gov_rating_economy<-zelig(satisfaction_gov ~ econ_decline*gov_conflict*vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F) ;     summary(gov_rating_economy)

		## check correlation between economic decline and policy dissatsifaction: only 0.33
		rcorr(gip$policy_discr_all, gip$econ_decline,type="pearson")
		cor(gip$policy_discr_all, gip$econ_decline, use="complete.obs")
		
##---------------------------------------------------------------
## Model 8-9: Government Ratings - gov vs opp, 20 policy areas
##---------------------------------------------------------------

  gov_rating_pa20s<-zelig(satisfaction_gov ~ policy_discr_all+gov_conflict+vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data= gip.know.cducsu.fdp,cite=F);  summary(gov_rating_pa20s)

  gov_rating_pa20<-zelig(satisfaction_gov ~ policy_discr_all*gov_conflict*vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data= gip.know.cducsu.fdp,cite=F) ;  summary(gov_rating_pa20)

  ## Save models
  model5<-gov_rating_economy_s1
  model6<-gov_rating_economy_s2
  model7<-gov_rating_economy
  model8<-gov_rating_pa20s
  model9<-gov_rating_pa20
  
##=================================================================================
## Show results presented in TABLE 3.3
##=================================================================================
  table3.3<-list(model5, model6, model7, model8,model9)
  screenreg(table3.3, digits=3)
  texreg(table3.3, digits=3) 		
  
##==================================================================================
## Get predicted values and substantive effects presented in Figure 3.2 (Chapter 3)
##==================================================================================

  ## Set values for policy economic decline
  
  ## coalition conflict
  c.min<-min(gip$gov_conflict, na.rm=T)
  c.max<-max(gip$gov_conflict, na.rm=T)
  q10.conflict<-quantile(gip$gov_conflict, prob=c(0.1), na.rm=T)
  q90.conflict<-quantile(gip$gov_conflict, prob=c(0.9), na.rm=T)
  c.low<-q10.conflict
  c.hi<-q90.conflict
  gov.c<-seq(c.min, c.max,length.out=50)
  
  ## economic decline
  mean.econ<-mean(gip$econ_decline, na.rm=T)
  sd.econ<-sd(gip$econ_decline, na.rm=T)
  min.econ.d<-min(gip$econ_decline, na.rm=T)
  max.econ.d<-max(gip$econ_decline, na.rm=T)
  econ.d<-seq(min.econ.d, max.econ.d, length.out=50)

  ## policy dissatisfaction (20 policy areas)
  mean.pa20<-mean(gip$policy_discr_all, na.rm=T)
  sd.pa20<-sd(gip$policy_discr_all, na.rm=T)
  min.pa20<-min(gip$policy_discr_all, na.rm=T)
  max.pa20<-max(gip$policy_discr_all, na.rm=T)
  pa20<-seq(min.pa20, max.pa20, length.out=50)

  
##################################
  ## ECONOMIC DECLINE
#################################  
    
##-------------------------------------------------------------------------------------------------------------
## Predicted governmen ratings given different values of ECONOMIC DECLINE for high and low coalition conflict
##-------------------------------------------------------------------------------------------------------------
  mod<-gov_rating_economy
  vote.gov<-NA; vote.gov<-1	
  
  ## government supporters, low conflict
  modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.low, woman =0, econ_decline = econ.d  )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  cl<-NA; 	cl<-res	# conflict low
  
  ## government supporters, high conflict
  modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.hi, woman =0, econ_decline = econ.d )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  ch<-NA; ch <-res	# conflict high
  
  ## save predicted values in separate onjects (will be used later to plot FIGURE 3.2)
  cl_gov.r_econ<-cl
  ch_gov.r_econ<-ch
  
##------------------------------------------------------------------------------------------------------
## Substantive Effect of ECONOMIC DECLINE (shift from mean-sd to mean +sd) 
## on government ratings given different values of coalition conflict
##------------------------------------------------------------------------------------------------------
  mod<-gov_rating_economy		
  
  ## GOV SUPPORTERS: marginal effect of econ (shift from mean-sd to mean +sd)
    ## economic decline low (mean-sd)
    vote.gov <-NA;vote.gov<-1
    modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ-sd.econ  )
    mods<-sim(mod, modx, num=10000)
    res<-NA; res<-get_qi(mods, xvalue="range")
    res<-as.data.frame(res); names(res)<-1:50
    me1_gov <-NA; me1_gov<-res	# econ decline low
  
  ## economic decline high (mean+sd)
    modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ+sd.econ )
    mods<-sim(mod, modx, num=10000)
    res<-NA; res<-get_qi(mods, xvalue="range")
    res<-as.data.frame(res); names(res)<-1:50
    me2_gov <-NA; me2_gov <-res	# econ decline high
  
  ## get substantive effect of econ decline: difference in predicted probabilities when econ is high and when econ is low (government supporters)
    me_gov<-me2_gov-me1_gov
  
  ## OPP SUPPORTERS: marginatl effect of econ (shift from mean-sd to mean +sd)
    ## economic decline low (mean-sd)
    vote.gov <-NA; vote.gov<-0
    modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ-sd.econ  )
    mods<-sim(mod, modx, num=10000)
    res<-NA; res<-get_qi(mods, xvalue="range")
    res<-as.data.frame(res); names(res)<-1:50
    me1_opp<-NA; me1_opp<-res	# econ decline low
  
    ## economic decline high (mean+sd)
    modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ+sd.econ )
    mods<-sim(mod, modx, num=10000)
    res<-NA; res<-get_qi(mods, xvalue="range")
    res<-as.data.frame(res); names(res)<-1:50
    me2_opp <-NA; me2_opp <-res	# econ decline high
  
  ## get substantive effect of econ decline: difference in predicted probabilities when econ is high and when econ is low (opposition supporters)
    me_opp<-me2_opp-me1_opp
  
  
  ## save substantive effect of econ decline in separate onjects (will be used later to plot FIGURE 3.2)
    me_gov_gov.r_econ<-me_gov
    me_opp_gov.r_econ<-me_opp
  
##################################################
## POLICY DISSATISFACTION (20 POLICY AREAS)
##################################################    
##------------------------------------------------------------------------------------------------------------------
## Predicted government ratings given different values of POLICY DISSATISFACTION and high and low coalition conflict
##-----------------------------------------------------------------------------------------------------------------

    mod<-gov_rating_pa20
    vote.gov<-1	## set to gov supporters
	
    ## low conflict
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.low, woman =0, policy_discr_all = pa20  )
		mods<-NA; mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		cl<-NA; cl<-res	# conflict low
		
		## high conflict
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.hi, woman =0, policy_discr_all = pa20 )
		mods<-NA;mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		ch<-NA; ch <-res	# conflict high
	
		## save predicted probabilities in separate onjects (will be used later to plot FIGURE 3.2)

		cl_gov.r_pa20<-cl
		ch_gov.r_pa20<-ch
		
		
##------------------------------------------------------------------------------------------------------
## Substantive Effect of POLICY DISSATISFACTION (20 policy areas) (shift from mean-sd to mean +sd) 
## on government ratings given different values of coalition conflict
##------------------------------------------------------------------------------------------------------
		
	
		mod<-NA; mod<-gov_rating_pa20

	
	## GOV SUPPORTERS: substantive effect of policy dissatisfaction (shift from mean-sd to mean +sd)
		
		vote.gov <-NA; vote.gov<-1		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20-(sd.pa20)  )
		mods<-NA; mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_gov <-NA; me1_gov<-res	# 20pa diss low
		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20 + (sd.pa20) )
		mods<-NA;mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_gov <-NA; me2_gov <-res	# 20a diss high

		## get substantive effect of policy dissatisfaction: 
		## difference in predicted gov ratings when policy dis is high and when policy dis is low (government supporters) 
		me_gov <-NA; me_gov<-me2_gov-me1_gov
	
	
	## OPP SUPPORTERS: substantive effect of policy dissatisfaction (shift from mean-sd to mean +sd)
		vote.gov <-NA; vote.gov<-0
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20-(sd.pa20))
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_opp <-NA; me1_opp<-res	# 20pa diss low
		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20 + (sd.pa20))
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_opp <-NA; me2_opp <-res	# 20pa diss high

		## get substantive effect of policy dissatisfaction: 
		## difference in predicted gov ratings when policy dis is high and when policy dis is low (opposition supporters) 
		
		me_opp<-me2_opp-me1_opp
	
		## save substantive effect of policy dissatisfaction in separate objects (will be used later to plot FIGURE 3.2) 
		me_gov_gov.r_pa20<-me_gov	
		me_opp_gov.r_pa20<-me_opp

	
################################################
### CDU/CSU VOTING
###############################################		
## Consider only those respondents who know that CDU/CSU is in the government, results with a full sample are essentially identical 			
		
##-------------------------------------------
## Model 10 -11: CDU/CSU Voting, Economy
##---------------------------------------------

	  ## Model 10
		cducsu_voting_economy_s <-zelig(vote_intention_cducsu ~ econ_decline+gov_conflict+ vote_le3 + cducsu_conflict + competence_cducsu_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction+ pol_know_all, model="logit", data= gip.know.cducsu); summary(cducsu_voting_economy_s)

		## Model 11
	  cducsu_voting_economy <-zelig(vote_intention_cducsu ~ econ_decline* gov_conflict* vote_le3 + cducsu_conflict + competence_cducsu_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction+ pol_know_all, model="logit", data= gip.know.cducsu) ; summary(cducsu_voting_economy)
	  
##-------------------------------------------------
## Model 12 & 13: CDU/CSU Voting, 20 policy areas
##------------------------------------------------

	  ## Model 12
  cducsu_voting_pa20_s <-zelig(vote_intention_cducsu ~ policy_discr_all+ gov_conflict+ vote_le3+ cducsu_conflict + competence_cducsu_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction+ pol_know_all, model="logit", data= gip.know.cducsu) ;  summary(cducsu_voting_pa20_s)
	
	  ## Model 13
  cducsu_voting_pa20 <-zelig(vote_intention_cducsu ~ policy_discr_all* gov_conflict* vote_le3+ cducsu_conflict + competence_cducsu_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction + financial_satisfaction + leisure_satisfaction+ pol_know_all, model="logit", data= gip.know.cducsu) ;  summary(cducsu_voting_pa20)
 

 ## save models
  model10<-cducsu_voting_economy_s
  model11<-cducsu_voting_economy
  model12<-cducsu_voting_pa20_s
  model13<-cducsu_voting_pa20
  
##=======================================================================================
## Show results presented in TABLE 3.4
##=======================================================================================
  
  table3.4<-list(model10, model11, model12, model13)
  screenreg(table3.4, digits=3)
  texreg(table3.4, digits=3) 		
  

  ##=======================================================================================
  
  ## show TABLES 3.2, 3.3, 3.4
  
  screenreg(table3.2, digits=3)
  texreg(table3.2, digits=3) 		
  
  screenreg(table3.3, digits=3)
  texreg(table3.3, digits=3) 		
  
  screenreg(table3.4, digits=3)
  texreg(table3.4, digits=3) 		
  
  ##=======================================================================================
  

##=======================================================================================
## GET information needed to plot FIGURE 3.3
##=======================================================================================
  
  
  
###############################
## ECONOMIC DECLINE
##############################  
  
  ##--------------------------------------------------------------------------------------------------------
  ## Predicted Probability given different values of economic decline for high and low coalitioin conflict
  ##--------------------------------------------------------------------------------------------------------  
  
  mod<-cducsu_voting_economy
  
  modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= c.low, woman =0, econ_decline = econ.d  )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  cl_cducsu<-NA; cl_cducsu <-res	# conflict low
  
  modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= c.hi, woman =0, econ_decline = econ.d )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  ch_cducsu<-NA; ch_cducsu <-res	# conflict high
  
  ## save predicted probabilities in separate models, will be used in FIGURE 3.3
  cl_cducsu_cducsu.v_econ<-cl_cducsu
  ch_cducsu_cducsu.v_econ<-ch_cducsu
  

  ##--------------------------------------------------------------------------------------------------------
  ## Substantive Effect of economic decline (shift from mean-sd (low) to mean +sd (high)) 
  ## on CDU/CSU voting given different  valus of coalition conflict
  ##--------------------------------------------------------------------------------------------------------
  
  mod<-cducsu_voting_economy
  
  ## CDUCSU SUPPORTERS: substantive effect of econ (shift from mean-sd (low) to mean +sd (high))
  
  modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= gov.c, woman =0, econ_decline = mean.econ-sd.econ )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  me1_gov <-NA; me1_gov<-res	# econ decline low
  
  modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= gov.c, woman =0, econ_decline = mean.econ+sd.econ )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  me2_gov <-NA; me2_gov <-res	# econ decline high
  
  ## get substantive effect of econ decline: 
  ## difference between the predicted probability when econ is high and when econ is low (CDU/CSU supporters)
  me_gov <-NA; me_gov<-me2_gov-me1_gov

  
  ## Opp SUPPORTERS: marginatl effect of econ (shift from mean-sd to mean +sd)
  modx<-setx(mod, vote_le3 = "opposition", gov_conflict= gov.c, woman =0, econ_decline = mean.econ-sd.econ )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  me1_opp <-NA; me1_opp<-res	# econ decline low
  
  modx<-setx(mod, vote_le3 = "opposition", gov_conflict= gov.c, woman =0, econ_decline = mean.econ+sd.econ )
  mods<-sim(mod, modx, num=10000)
  res<-NA; res<-get_qi(mods, xvalue="range")
  res<-as.data.frame(res); names(res)<-1:50
  me2_opp <-NA; me2_opp <-res	# econ decline high
  
  ## get substantive effect of econ decline: 
  ## difference between the predicted probability when econ is high and when econ is low (opposition supporters)
  
  me_opp <-NA; me_opp<-me2_opp-me1_opp
  
  
  ## save substantive effects in separate objects, will be used to plot FIGURE 3.3
  me_cducsu_cducsu.v_econ<-me_gov
  me_opp_cducsu.v_econ<-me_opp
  

##########################################
## POLICY DISSATISFACTION (20 polcy areas)
########################################## 
		
	## ------------------------------------------------------------------------------------------
  ## Get predicted probability to vote for CDU/CSU given 
  ## different values of policy dissatisfaction and coailition conflict, by party supporters
  ## ------------------------------------------------------------------------------------------
  
  mod<-NA; mod<-cducsu_voting_pa20
		
		## CDUCSU
		## low coalition conflict
    modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= c.low, woman =0, policy_discr_all = pa20  )
		mods<-NA; mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		cl_cducsu<-NA; cl_cducsu <-res	# conflict low
		
		## high coalition conflict
		modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= c.hi, woman =0, policy_discr_all = pa20 )
		mods<-NA;mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		ch_cducsu<-NA; ch_cducsu <-res	# conflict high
	
		## OPPOSITION
		## low coalition conflict
		modx<-setx(mod, vote_le3 = "opposition", gov_conflict= c.low, woman =0, policy_discr_all = pa20  )
		mods<-NA; mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		cl_opp<-NA; cl_opp <-res	# conflict low
		
		## high coalition conflict
		modx<-setx(mod, vote_le3 = "opposition", gov_conflict= c.hi, woman =0, policy_discr_all = pa20 )
		mods<-NA;mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		ch_opp<-NA; ch_opp <-res	# conflict high
		
		
		## Save predicted probability in separate objects, will be used in FIGURE 3.3
		cl_cducsu.cducsu.v_pa20<-cl_cducsu
		ch_cducsu.cducsu.v_pa20<-ch_cducsu

		cl_opp.cducsu.v_pa20<-cl_opp
		ch_opp.cducsu.v_pa20<-ch_opp
		
		
##---------------------------------------------------------------------------------------
## Substantive Effect of POLICY DISSATISFACTION (20 policy areas) (shift from mean-sd (low) to mean +sd (high))
## on CDU/CSU Voting by party groups		
##---------------------------------------------------------------------------------------	
		mod<-NA; mod<-cducsu_voting_pa20

	## CDU/CSU SUPPORTERS: substantive effect of policy dissatisfaction (shift from mean-sd (low) to mean +sd (high))
		
		## low policy dissatisfaction
		modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20-(sd.pa20)  )
		mods<-NA; mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_gov <-NA; me1_gov<-res	# 20pa diss low
		
		## high policy dissatisfaction
		modx<-setx(mod, vote_le3 = "cducsu", gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20 + (sd.pa20) )
		mods<-NA;mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_gov <-NA; me2_gov <-res	# 20a diss high

		## get substantive effect of policy dissatisfaction on CDU/CSU voting for different values of coalition conflict: 
		## difference between the predicted prbabilities when policy dis is high and when policy dis is low (CDU/CSU supporters)
		me_gov <-NA; me_gov<-me2_gov-me1_gov
	
	
	## OPP SUPPORTERS: marginatl effect of econ (shift from mean-sd to mean +sd)
		
		vote.gov <-NA; vote.gov<-0
		## low policy dissatisfaction
		modx<-setx(mod, vote_le3 = "opposition", gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20-(sd.pa20))
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_opp<-NA; me1_opp<-res	# 20pa diss low
		
		## high policy dissatisfaction
		modx<-setx(mod, vote_le3 = "opposition", gov_conflict= gov.c, woman =0, policy_discr_all = mean.pa20 + (sd.pa20))
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_opp <-NA; me2_opp <-res	# 20pa diss high

		## get substantive effect of policy dissatisfaction on CDU/CSU voting for different values of coalition conflict: 
		## difference between the predicted prbabilities when policy dis is high and when policy dis is low (Opposition supporters)
		me_opp <-NA; me_opp<-me2_opp-me1_opp
	
		## save substantive effects of policy dis in separate objects, will be used in FIGURE 3.3
		me_cducsu.cducsu.v_pa20<-me_gov
		me_opp.cducsu.v_pa20<-me_opp
		
	
		##=======================================================================================
		## Plot FIGURE 3.2 - Government ratings
		##=======================================================================================
		
	
		pdf(file="./robustness checks/graphs/figure3.2_gov.r_all_respondents.pdf", bg="transparent",width=8, height=6.5)
		
		par(mfrow=c(2,3))		
		par(oma=c(2,2,2,2))
		par(mar=c(5,4,5,1))
		
		##-------------------------------
		## Government RAtings - ECON
		##-------------------------------
		
		## Gov Ratings -  Predicted RAtings; ECON 
		
		plot(y=c(0,10), x=c(1,4), type="n", xlab="Economic Decline", ylab="Predicted Gov Ratings", las=1, main=" ", cex.main=1, cex.lab=1.2) 
		
		lines(x= econ.d,y=apply(cl_gov.r_econ,2, mean), lwd=2, col="gray")
		lines(x= econ.d,y=apply(cl_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= econ.d,y=apply(cl_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		
		
		lines(x= econ.d,y=apply(ch_gov.r_econ,2, mean), lwd=2, col="black")
		lines(x= econ.d,y=apply(ch_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= econ.d,y=apply(ch_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		
		legend(1.8,10,col=c("black","gray"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.7)
		title("Predicted Gov Ratings\n Gov Supporters", line=0.5, cex.main=1)
		
		
		## Gov Ratings, ME - Gov, ECON
		
		plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, mean), lwd=2, col="black")
		lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		abline(h=0, col="red")
		title("Effect of Economic Decline\n Gov Supporters", line=0.5, cex.main=1)
		mtext(text="Impact of Economic Decline on Gov Ratings", side=3, line=3.5, outer=F)
		mtext(text="Impact of Policy Dissatisfaction (20 Policy Areas) on Gov Ratings", side=1, line=5.5, outer=F)
		
		
		## Gov Ratings, ME - Opp, ECON
		
		plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, mean), lwd=2, col="gray")
		lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		abline(h=0, col="red")
		
		title("Effect of Economic Decline \n Opp Supporters", line=0.5, cex.main=1)
		
		
		##-------------------------------
		## Government Ratings - PA20
		##-------------------------------
		
		## Gov Ratings- Predicted Ratings; PA20
		
		
		plot(y=c(0,10), x=c(0,2), type="n", xlab="Policy Dissatisfaction (20 Areas)", ylab="Predicted Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= pa20,y=apply(cl_gov.r_pa20,2, mean), lwd=2, col="gray")
		lines(x= pa20,y=apply(cl_gov.r_pa20,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= pa20,y=apply(cl_gov.r_pa20,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		
		
		lines(x= pa20,y=apply(ch_gov.r_pa20,2, mean), lwd=2, col="black")
		lines(x= pa20,y=apply(ch_gov.r_pa20,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= pa20,y=apply(ch_gov.r_pa20,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		
		legend(0.5,10,col=c("black","gray"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.7)
		title("Predicted Gov Ratings\n Gov Supporters", line=0.5, cex.main=1)
		
	
		## Gov Ratings, ME - Gov, PA20
		plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_gov_gov.r_pa20,2, mean), lwd=2, col="black")
		lines(x= gov.c,y=apply(me_gov_gov.r_pa20,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= gov.c,y=apply(me_gov_gov.r_pa20,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		abline(h=0, col="red")
		title("Effect of Policy Dissatisfaction\n Gov Supporters", line=0.5, cex.main=1)
		
		
		## Gov Ratings, ME - Opp, PA20
		plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effecg on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_opp_gov.r_pa20,2, mean), lwd=2, col="gray")
		lines(x= gov.c,y=apply(me_opp_gov.r_pa20,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= gov.c,y=apply(me_opp_gov.r_pa20,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		abline(h=0, col="red")
		
		title("Effect of Policy Dissatisfaction\n Opp Supporters", line=0.5, cex.main=1)
		
		
		
		dev.off()
		
		

		##=======================================================================================
		## FIGURE 3.3 - ALL RESPONDENTS
		##=======================================================================================
		
		pdf(file="./robustness checks/graphs/figure3.3_cducsu_v_all_respondents.pdf", bg="transparent",width=8, height=6.5) # 8, 6.5
		
		par(mfrow=c(2,3))		
		par(oma=c(2,2,2,2))
		par(mar=c(5,4,5,1))
		
		
		##-------------------------------
		## CDUCSU - ECON
		##-------------------------------
		
		## CDUCSU Vote: Predicted probability: ECON

		plot(y=c(0,1), x=c(1,4), type="n", xlab="Economic Decline", ylab="CDU/CSU Voting Probability", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= econ.d,y=apply(cl_cducsu_cducsu.v_econ,2, mean), lwd=2, col="gray")
		lines(x= econ.d,y=apply(cl_cducsu_cducsu.v_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= econ.d,y=apply(cl_cducsu_cducsu.v_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		
		lines(x= econ.d,y=apply(ch_cducsu_cducsu.v_econ,2, mean), lwd=2, col="black")
		lines(x= econ.d,y=apply(ch_cducsu_cducsu.v_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= econ.d,y=apply(ch_cducsu_cducsu.v_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		
		legend(1,0.2,col=c("black","gray"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.8)
		title("CDU/CSU Voting Probability \n CDU/CSU  Supporters", line=0.5, cex.main=1)
		
		## CDUCSU Vote, ME - CDUCSU, ECON
		
		plot(y=c(-0.8,+0.5), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_cducsu_cducsu.v_econ,2, mean), lwd=2, col="black")
		lines(x= gov.c,y=apply(me_cducsu_cducsu.v_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= gov.c,y=apply(me_cducsu_cducsu.v_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		abline(h=0, col="red")
		
		
		title("Effect of Economic Decline\n CDUCSU Supporters", line=0.5, cex.main=1)
		mtext(text="Impact of Economic Decline on CDU/CSU Vote", side=3, line=3, outer=F)
		mtext(text="Impact of Policy Dissatisfaction (20 Policy Areas) on CDU/CSU Vote", side=1, line=5.5, outer=F)
		
		
		
		## CDUCSU Vote, ME - Opp, ECON
		
		
		plot(y=c(-0.8,+0.5), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_opp_cducsu.v_econ,2, mean), lwd=2, col="gray")
		lines(x= gov.c,y=apply(me_opp_cducsu.v_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= gov.c,y=apply(me_opp_cducsu.v_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		abline(h=0, col="red")
		
		title("Effect of Economic Decline \n Opposition Supporters", line=0.5, cex.main=1)
		
	
		## CDUCSU Vote: Predicted probability: PA20
		
		plot(y=c(0,1), x=c(0,2), type="n", xlab="Dissatisfaction (20 Areas)", ylab="CDU/CSU Voting Probability ", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= pa20,y=apply(cl_cducsu.cducsu.v_pa20,2, mean), lwd=2, col="gray")
		lines(x= pa20,y=apply(cl_cducsu.cducsu.v_pa20,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= pa20,y=apply(cl_cducsu.cducsu.v_pa20,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		
		
		lines(x= pa20,y=apply(ch_cducsu.cducsu.v_pa20,2, mean), lwd=2, col="black")
		lines(x= pa20,y=apply(ch_cducsu.cducsu.v_pa20,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= pa20,y=apply(ch_cducsu.cducsu.v_pa20,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		
		legend(0,0.2,col=c("black","gray"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.8)
		title("CDU/CSU Voting Probability\n CDU/CSU Supporters", line=0.5, cex.main=1)
		

		## CDUCSU Vote, ME - CDUCSU, PA20
		
		plot(y=c(-0.8,+0.5), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_cducsu.cducsu.v_pa20,2, mean), lwd=2, col="black")
		lines(x= gov.c,y=apply(me_cducsu.cducsu.v_pa20,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		lines(x= gov.c,y=apply(me_cducsu.cducsu.v_pa20,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		abline(h=0, col="red")
		title("Effect of Policy Dissatisfaction\n CDU/CSU Supporters", line=0.5, cex.main=1)
		
	
		## CDUCSU Vote, ME - Opp, PA20
		
		plot(y=c(-0.8,+0.5), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on CDU/CSU Vote", las=1, main="", cex.main=1, cex.lab=1.2) 
		
		lines(x= gov.c,y=apply(me_opp.cducsu.v_pa20,2, mean), lwd=2, col="gray")
		lines(x= gov.c,y=apply(me_opp.cducsu.v_pa20,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		lines(x= gov.c,y=apply(me_opp.cducsu.v_pa20,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		abline(h=0, col="red")
		title("Effect of Policy Dissatisfaction\n Opposition Supporters", line=0.5, cex.main=1)
		
		
		dev.off()
		
						
				
