## For Angelova (2018) Dissertation Chapter 3: Coalition Conflict - a Remedy for Democratic Accountability?
## Replicate Models 5,6,7 (Government ratings) with split samples: economic improvement (those who indicate economic improvement or neither improvement nor decline) and economic decline (those who indicated economic decline or neither improvement nor declince)
## Results are presented in Appendix B, TABLE B.2 and FIGURE B.2


## All analyses, simulations, tables, and figures were created on OS 10.13.6 (High Sierra) using R version 3.5.0 (2018-04-23) and Zelig version Zelig 5.1.6 (note that newer and older versions of Zelig use different syntax)
### Before running this script run the following R script to get GIP data provided via Gesis: source('./1_replication_file_get_data.R')



## set working directory
setwd("~/Documents/Dissertation/Diss - Replication - Chapter 3")

## clean working space
rm(list = ls(all = TRUE))

print(sessionInfo())

## get packages
library("Zelig")
library("mlogit")
library("nnet")
library("memisc")
library("stargazer")
library("xtable")
library("texreg")
library("stargazer")
library("Hmisc")
library("MASS")

## get gip data

load(file="./gip_data/gip.rda") # this data is created in script ./1_replication_file_get_data.R
gip.backup<-gip
dim(gip.backup)
options(signif.symbols=c("***"=.001,"**"=.01,"*"=.05,"'"=.1))

## run additional variable modifications
source('./var_modifications.R')

gip$vote_le3_orig<-as.factor(gip$vote_last_election_cducsu_fdp_opp)
gip$vote_le3<-relevel(gip$vote_le3_orig, ref="opposition")
gip.full<-gip
dim(gip.full)

## KEEP only those with perceptions of economic DECLINE

		gip<-gip.full[gip.full$econ_decline>=2,] # keep 0,1,2 ()
	 	unique(gip[,c("CE02055","econ_decline")])	
	 	gip$econ_decline_model<-gip$econ_decline
	 	gip$econ_decline<-gip$econ_decline_model-2

 		## keep only respondents from second wave
		gip<-gip[gip$gip2==1,]
	
	
		## select only these who know that FDP and CDU/CSU are gov parties
		gip.know.cducsu.fdp<-gip[ gip$gov_knowledge_fdp==1 & gip$gov_knowledge_cducsu==1,]
		gip.know.cducsu<-gip[gip$gov_knowledge_cducsu==1,]
		gip.know.fdp<-gip[ gip$gov_knowledge_fdp==1,]
	
	
##----------------------------------------------------------------
## Replicate models: 5,6,7 (Government Ratings): ECONOMIC DECLINE
##-----------------------------------------------------------------

		## control
		unique(gip[,c("CE02055","econ_decline","econ_improve")])	

  gov_rating_economy_s<-zelig(satisfaction_gov ~ econ_decline+gov_conflict+vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F) ; summary(gov_rating_economy_s)

  gov_rating_economy_s2<-zelig(satisfaction_gov ~ econ_decline*gov_conflict+vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F) ; summary(gov_rating_economy_s2)


  gov_rating_economy<-zelig(satisfaction_gov ~ econ_decline*gov_conflict*vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F) ; summary(gov_rating_economy)


## save models
model1<-gov_rating_economy_s
model2<-gov_rating_economy_s2
model3<-gov_rating_economy



	## Set values
  ## coalition conflict
	c.min<-min(gip$gov_conflict, na.rm=T)
	c.max<-max(gip$gov_conflict, na.rm=T)
	q10.conflict<-quantile(gip$gov_conflict, prob=c(0.1), na.rm=T)
	q90.conflict<-quantile(gip$gov_conflict, prob=c(0.9), na.rm=T)
	c.low<-q10.conflict
	c.hi<-q90.conflict
	gov.c<-seq(c.min, c.max,length.out=50)

  ## economic decline
	mean.econ<-mean(gip$econ_decline, na.rm=T)
	sd.econ<-sd(gip$econ_decline, na.rm=T)
	min.econ.d<-min(gip$econ_decline, na.rm=T)
	max.econ.d<-max(gip$econ_decline, na.rm=T)
	econ.d<-seq(min.econ.d, max.econ.d, length.out=50)
	econ.d_dec<-econ.d
	quantile(gip$econ_decline, prob=c(0.1,0.9), na.rm=T)
	quantile(gip$econ_decline, prob=c(0.05,0.95), na.rm=T)

##------------------------------------------------------------------------------------------------------------
## Predicted government ratings given different values of economic decline for high and low coalition conflict
##------------------------------------------------------------------------------------------------------------		
	
	  mod<-gov_rating_economy
		vote.gov<-NA; vote.gov<-1	

		## coalition conflict low
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.low, woman =0, econ_decline = econ.d  )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		cl<-NA; cl<-res	# conflict low
		
		## coalition conflict high
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.hi, woman =0, econ_decline = econ.d )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		ch<-NA; ch <-res	# conflict high
	
		cl_gov.r_econ<-cl
		ch_gov.r_econ<-ch
		

	
	##-----------------------------------------------------------------------------------
	## Substantive effect of economic decline on government ratings by party supporters
	##-----------------------------------------------------------------------------------
	
	mod<-NA; mod<-gov_rating_economy		

	## GOV SUPPORTERS: marginal effect of econ (shift from mean-sd to mean +sd)
		vote.gov <-NA;vote.gov<-1
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ-sd.econ  )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_gov <-NA; me1_gov<-res	# econ decline low
		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ+sd.econ )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_gov <-NA; me2_gov <-res	# econ decline high

		me_gov<-me2_gov-me1_gov
	

	## OPP SUPPORTERS: marginal effect of econ (shift from mean-sd to mean +sd)
		vote.gov <-NA; vote.gov<-0
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ-sd.econ  )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_opp<-NA; me1_opp<-res	# econ decline low
		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_decline = mean.econ+sd.econ )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_opp <-NA; me2_opp <-res	# econ decline high

		me_opp<-me2_opp-me1_opp
	
		
		## save substantive effects in separate objects, needed or Figure B.2 (appendix)
		me_gov_gov.r_econ<-me_gov
		me_opp_gov.r_econ<-me_opp
		


		
		
##------------------------------------------------------------------	
## KEEP only those with perceptions of economic IMPROVEMENT
##------------------------------------------------------------------
	
		gip<-gip.full[gip.full$econ_decline<=2,] # keep 0,1,2 ()
		unique(gip[,c("CE02055","econ_decline","econ_improve")])	
		
		gip$econ_improve_orig<-gip$econ_improve
		gip$econ_improve<-gip$econ_improve_orig-2
		unique(gip[,c("CE02055","econ_decline","econ_improve","econ_improve_orig")])	
		  
	 	## keep only respondents from second wave
		gip<-gip[gip$gip2==1,]
	
		## select only these who know that FDP and CDU/CSU are gov parties
		gip.know.cducsu.fdp<-gip[ gip$gov_knowledge_fdp==1 & gip$gov_knowledge_cducsu==1,]
		gip.know.cducsu<-gip[gip$gov_knowledge_cducsu==1,]
		gip.know.fdp<-gip[ gip$gov_knowledge_fdp==1,]
	

		
##---------------------------------------------------------------------------
##Replicate model 5,6,7: Government Ratings - with economic improvement
##---------------------------------------------------------------------------

		
unique(gip[,c("CE02055","econ_decline","econ_improve")])	

gov_rating_economy_s<-zelig(satisfaction_gov ~ econ_improve +gov_conflict+vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F) ; summary(gov_rating_economy_s)


gov_rating_economy_s2<-zelig(satisfaction_gov ~ econ_improve*gov_conflict+vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F) ; summary(gov_rating_economy_s2)


gov_rating_economy<-zelig(satisfaction_gov ~ econ_improve*gov_conflict*vote_le_gov+cducsu_conflict + fdp_conflict+ competence_gov_nas_as_0+ age_cat + woman + education + religion_activity + family_satisfaction +financial_satisfaction+ leisure_satisfaction+ pol_know_all, model="ls", data=gip.know.cducsu.fdp,cite=F) ; summary(gov_rating_economy)



## save models
model4<-gov_rating_economy_s
model5<-gov_rating_economy_s2
model6<-gov_rating_economy

##-------------------------------------------------------------------------------------------------------
## Get predicted government ratings and substantive effect of ECONOMIC IMPROVEMENT on government ratings
##-------------------------------------------------------------------------------------------------------

  ## set values - economic improvement
	mean.econ<-mean(gip$econ_improve, na.rm=T)
	sd.econ<-sd(gip$econ_improve, na.rm=T)
	min.econ.d<-min(gip$econ_improve, na.rm=T)
	max.econ.d<-max(gip$econ_improve, na.rm=T)
	econ.d<-seq(min.econ.d, max.econ.d, length.out=50)
	econ.d_imp<-econ.d

##-------------------------------------------------------------------------------------------------------
## Predicted Probability given different values of economic decline for high and low government conflict
##-------------------------------------------------------------------------------------------------------
	
		mod<-gov_rating_economy
		vote.gov<-NA; vote.gov<-1	

		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.low, woman =0, econ_improve = econ.d  )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		cl<-NA; cl<-res	# conflict low
		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= c.hi, woman =0, econ_improve = econ.d )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		ch<-NA; ch <-res	# conflict high
	
		cl_gov.r_econ_imp<-cl
		ch_gov.r_econ_imp<-ch
		
		
##-------------------------------------------------------------------------------------------------------
## Substantive Effect of economic improvement
##-------------------------------------------------------------------------------------------------------		
		mod<-gov_rating_economy		

	## GOV SUPPORTERS: marginal effect of econ (shift from mean-sd to mean +sd)
		vote.gov <-NA;vote.gov<-1
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_improve = mean.econ-sd.econ  )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_gov <-NA; me1_gov<-res	# econ decline low
		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_improve = mean.econ+sd.econ )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_gov <-NA; me2_gov <-res	# econ decline high

		me_gov<-me2_gov-me1_gov
	
	
	
	## OPP SUPPORTERS: marginatl effect of econ (shift from mean-sd to mean +sd)
		vote.gov <-NA; vote.gov<-0
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_improve = mean.econ-sd.econ  )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me1_opp<-NA; me1_opp<-res	# econ decline low
		
		modx<-setx(mod, vote_le_gov = vote.gov, gov_conflict= gov.c, woman =0, econ_improve = mean.econ+sd.econ )
		mods<-sim(mod, modx, num=10000)
		res<-NA; res<-get_qi(mods, xvalue="range")
		res<-as.data.frame(res); names(res)<-1:50
		me2_opp <-NA; me2_opp <-res	# econ decline high

		me_opp<-me2_opp-me1_opp
	
		
		## save substantive effects in separate objects
		me_gov_gov.r_econ_imp<-me_gov
		me_opp_gov.r_econ_imp<-me_opp
		
		

	
##-------------------------------------------------------------------------------------------------------		
### TABLE B.2 (Appendix)			
##-------------------------------------------------------------------------------------------------------
		tableB.2<-list(model1, model2, model3, model4,model5,model6)
		screenreg(tableB.2, digits=3)
		texreg(tableB.2, digits=3) 		
	
##-------------------------------------------------------------------------------------------------------				
## FIGURE B.2 (Appendix)
##-------------------------------------------------------------------------------------------------------				
		
		pdf(file="./robustness checks/graphs/figureB.2_appendix_split_sample.pdf", bg="transparent",width=8, height=6.5)
		
		par(mfrow=c(2,3))		
		par(oma=c(2,2,2,2))
		par(mar=c(5,4,5,1))
		
##-----------------------------------------------
## Government Ratings - ECONOMIC DECLINE
##-----------------------------------------------
		
		### Predicted government ratings
		  plot(y=c(0,10), x=c(0,2), type="n", xlab="Economic Decline", ylab="Predicted Gov Ratings", las=1, main=" ", cex.main=1, cex.lab=1.2) 
		  # low conflict
		  lines(x= econ.d_dec,y=apply(cl_gov.r_econ,2, mean), lwd=2, col="gray")
	  	lines(x= econ.d_dec,y=apply(cl_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		  lines(x= econ.d_dec,y=apply(cl_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
	  	# high conflict
		  lines(x= econ.d_dec,y=apply(ch_gov.r_econ,2, mean), lwd=2, col="black")
		  lines(x= econ.d_dec,y=apply(ch_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		  lines(x= econ.d_dec,y=apply(ch_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		  legend(0,10,col=c("black","gray"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.9)
		  title("Predicted Government Ratings\n Gov Supporters", line=0.5, cex.main=1)
		
		### substantive effect 
	  	## government supporters
		  plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		  lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, mean), lwd=2, col="black")
		  lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		  lines(x= gov.c,y=apply(me_gov_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		  abline(h=0, col="red")
		  title("Effect of Economic Decline\n Gov Supporters", line=0.5, cex.main=1)
		  mtext(text="Impact of Economic Decline on Gov Ratings", side=3, line=3.5, outer=F)
	  	mtext(text="Impact of Economic Improvement on Gov Ratings", side=1, line=5.5, outer=F)
		
		  ## opposition supporters
		  plot(y=c(-4,+2), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		  lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, mean), lwd=2, col="gray")
		  lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		  lines(x= gov.c,y=apply(me_opp_gov.r_econ,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		  abline(h=0, col="red")
		  title("Effect of Economic Decline \n Opp Supporters", line=0.5, cex.main=1)
		
##------------------------------------------------------------
## Government Ratings - ECONOMIC IMPROVEMENT
##------------------------------------------------------------
		
		
		## predicted government ratings
		plot(y=c(0,10), x=c(0,2), type="n", xlab="Economic Improvement", ylab="Predicted Gov Ratings", las=1, main=" ", cex.main=1, cex.lab=1.2) 
		  ## low conflict
		  lines(x= econ.d_imp,y=apply(cl_gov.r_econ_imp,2, mean), lwd=2, col="gray")
		  lines(x= econ.d_imp,y=apply(cl_gov.r_econ_imp,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		  lines(x= econ.d_imp,y=apply(cl_gov.r_econ_imp,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
	  	## high conflict
		  lines(x= econ.d_imp,y=apply(ch_gov.r_econ_imp,2, mean), lwd=2, col="black")
		  lines(x= econ.d_imp,y=apply(ch_gov.r_econ_imp,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
	  	lines(x= econ.d_imp,y=apply(ch_gov.r_econ_imp,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
	
		  legend(0,2.3,col=c("black","gray"), lwd=c(2,2), legend=c("High Conflict","Low Conflict"), cex=0.9)
		  title("Predicted Gov Ratings\n Gov Supporters", line=0.5, cex.main=1)
		
	  ## substantive effect of economic improvement
		  ## government supporters
	  	plot(y=c(-2,+4), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		  lines(x= gov.c,y=apply(me_gov_gov.r_econ_imp,2, mean), lwd=2, col="black")
		  lines(x= gov.c,y=apply(me_gov_gov.r_econ_imp,2, quantile,prob=0.025), lwd=1, col="black", lty=2)
		  lines(x= gov.c,y=apply(me_gov_gov.r_econ_imp,2, quantile,prob=0.975), lwd=1, col="black", lty=2)
		  abline(h=0, col="red")
		  title("Effect of Economic Improvement\n Gov Supporters", line=0.5, cex.main=1)
		
		  ##  opposition supporters
		  plot(y=c(-2,+4), x=c(c.low,c.hi), type="n", xlab="Coalition Conflict", ylab="Effect on Gov Ratings", las=1, main="", cex.main=1, cex.lab=1.2) 
		  lines(x= gov.c,y=apply(me_opp_gov.r_econ_imp,2, mean), lwd=2, col="gray")
		  lines(x= gov.c,y=apply(me_opp_gov.r_econ_imp,2, quantile,prob=0.025), lwd=1, col="gray", lty=2)
		  lines(x= gov.c,y=apply(me_opp_gov.r_econ_imp,2, quantile,prob=0.975), lwd=1, col="gray", lty=2)
		  abline(h=0, col="red")
		  title("Effect of Economic Improvement \n Opp Supporters", line=0.5, cex.main=1)
		
		dev.off()
		
		
		



