## Replication of Model 11 and Model 13 (vote for CDU/CSU with three fold interaction between last vote, coalition conflict, and policy dissatsifaction (econ, 20 policy areas) with multinomial logit models
## only those respondents who know that CDU/CSU was a government party


## Get predicted probabilities with confidence intervals - via boostrapping
## before running this script run script "1_replication_file_get_data.R" AND then "TABLE B.3, B.4_appendix - multinomial logit.R"




## ---------------------------------------   
## bootstrapping
## ---------------------------------------   



## specifications
ids<-unique(mdata$id_g_gip1)
unique.cases<-length(ids)

## create empty matrix to save restuls and interemediate steps
nsim<-100

info.drawn.ids<-matrix(NA, ncol=nsim, nrow= unique.cases)
info.drawn.cases<-matrix(NA, ncol=nsim, nrow= unique.cases)
pp.for.given.party.Hcon<-matrix(NA, ncol=nsim, nrow= 50)
pp.for.given.party.Lcon<-matrix(NA, ncol=nsim, nrow= 50)


## simulations specifications
econ<-seq(0,4, length.out=50)
pa<-seq(0,max(mdata$policy_discr_all), length.out=50)

## set partisanship
party.supporter<-"cducsu"
vote.for<-"cducsu"



## economic decline
res2<-res_econ



for(i in 90: nsim){
  
  
  ## do a random draw from the unique respondents with replacment
  draw<-NA
  draw<-sample(1: unique.cases, unique.cases,replace=T)
  
  
  ## create new data with these ids
  new.data<-NA
  new.data<-data[draw,]
  
  ## save ids for control
  info.drawn.ids[,i]<-new.data$id_g_gip1
  info.drawn.cases[,i]<-draw
  
  ## create new mlogit data with the drawn people 	
  new.mdata<-NA
  new.mdata <- mlogit.data(new.data, shape="wide",  choice="vote_int",varying=15:29)
  head(new.mdata)
  table(new.mdata$id_g_gip1)
  
  ## run analyses with new mlogit data
  
  
  ## ECON
   res.boot<-NA
   res.boot <-mlogit(vote_int~ vote_le+conflict+competence | 
   I(econ_decline*gov_conflict) + econ_decline + gov_conflict + I(vote_le*econ_decline) + I(vote_le*gov_conflict) + I(vote_le*econ_decline*gov_conflict)+age_cat+woman+education+family_satisfaction+financial_satisfaction+leisure_satisfaction+ religion_activity+ pol_know_all, new.mdata, reflevel="spd")
   summary(res.boot)
  
  
  
  ## run simulations with results
  
  ## HIGH Conflict
  sim.Hcon<-NA
  sim.Hcon<-with(new.mdata,
                 expand.grid(alt = unique(alt),
                             econ_decline =econ,
                             gov_conflict = 9 ,
                             vote_le = 1,
                             conflict = mean(conflict), 
                             competence=max(competence),
                             age_cat= mean(age_cat),
                             woman=0,
                             education=mean(education),
                             religion_activity=data$religion_activity[1],
                             family_satisfaction=mean(family_satisfaction),
                             financial_satisfaction=mean(financial_satisfaction),
                             leisure_satisfaction=mean(leisure_satisfaction),
                             pol_know_all=mean(pol_know_all)
                             
                 ))
  
  # define party supporter 
  ## set the last vote variable to 0 for all parties besides the specified "party.supporter")    		
  sim.Hcon$vote_le[sim.Hcon$alt!= party.supporter]<-0
  
  
  ## LOW Conflict
  sim.Lcon<-NA
  sim.Lcon<-sim.Hcon
  sim.Lcon$gov_conflict<-4
  
  
  ## get predicted probabilities
  pp.Hcon.boot<-NA; pp.Hcon.boot<-predict(res.boot, sim.Hcon)
  pp.Lcon.boot<-NA; pp.Lcon.boot<-predict(res.boot, sim.Lcon)
  
  ## save pp to vote for a given party (here for cducsu)
  pp.for.given.party.Hcon[,i]<-pp.Hcon.boot[, "cducsu"]
  pp.for.given.party.Lcon[,i]<-pp.Lcon.boot[, "cducsu"]
  
  cat('\nIteration', i, "from",nsim,'complete, Time:')
  time<-Sys.time()
  print(time[1])	
  flush.console()
  
  
} # close i loop


## ##################################### 
## get mean and CI from the simulations
## ##################################### 

## create empty matrix
ppHcon<-matrix(NA, ncol=3, nrow= 50); colnames(ppHcon)<-c("mean","low","high")
ppLcon<-matrix(NA, ncol=3, nrow= 50); colnames(ppLcon)<-c("mean","low","high")

## get mean, and confidence interevals
## HIGH CONFLICT
ppHcon[,"mean"]<-apply(pp.for.given.party.Hcon,1, mean) # rows are econ values, columns are separate simulation
ppHcon[,"low"]<-apply(pp.for.given.party.Hcon,1, quantile,prob=0.025)
ppHcon[,"high"]<-apply(pp.for.given.party.Hcon,1, quantile,prob= 0.975)
## LOW CONFLICT
ppLcon[,"mean"]<-apply(pp.for.given.party.Lcon,1, mean) # rows are econ values, columns are separate simulation
ppLcon[,"low"]<-apply(pp.for.given.party.Lcon,1, quantile,prob=0.025)
ppLcon[,"high"]<-apply(pp.for.given.party.Lcon,1, quantile,prob= 0.975)



##############################################
## POLICY DISSATISFACTION
##############################################

## create empty matrix to save restuls and interemediate steps
nsim<-100

info.drawn.ids<-matrix(NA, ncol=nsim, nrow= unique.cases)
info.drawn.cases<-matrix(NA, ncol=nsim, nrow= unique.cases)
pp.for.given.party.Hcon<-matrix(NA, ncol=nsim, nrow= 50)
pp.for.given.party.Lcon<-matrix(NA, ncol=nsim, nrow= 50)


## set partisanship
party.supporter<-"cducsu"
vote.for<-"cducsu"


## 20 policy areas
res2<-res_pa

for(i in 89: nsim){
  
  
  ## do a random draw from the unique respondents with replacment
  draw<-NA
  draw<-sample(1: unique.cases, unique.cases,replace=T)
  
  ## create new data with these ids
  new.data<-NA
  new.data<-data[draw,]
  
  ## save ids for control
  info.drawn.ids[,i]<-new.data$id_g_gip1
  info.drawn.cases[,i]<-draw
  
  ## create new mlogit data with the drawn people 	
  new.mdata<-NA
  new.mdata <- mlogit.data(new.data, shape="wide",  choice="vote_int",varying=15:29)
  head(new.mdata)
  table(new.mdata$id_g_gip1)
  
  ## run analyses with new mlogit data
  
  
  
  # 20 POLICY AREAS
  res.boot<-NA
  res.boot <-mlogit(vote_int~ vote_le+conflict+competence | 
                      I(policy_discr_all*gov_conflict) + policy_discr_all + gov_conflict + I(vote_le* policy_discr_all) + I(vote_le*gov_conflict) + I(vote_le* policy_discr_all*gov_conflict)+age_cat+woman+education+family_satisfaction+financial_satisfaction+leisure_satisfaction+ religion_activity+ pol_know_all, new.mdata, reflevel="spd")
  # summary(res.boot)
  

  ## run simulations with results
  
  ## HIGH Conflict
  sim.Hcon<-NA
  sim.Hcon<-with(new.mdata,
                 expand.grid(alt = unique(alt),
                             policy_discr_all=pa, 
                             gov_conflict = 9 ,
                             vote_le = 1,
                             conflict = mean(conflict), 
                             competence=max(competence),
                             age_cat= mean(age_cat),
                             woman=0,
                             education=mean(education),
                             religion_activity=data$religion_activity[1],
                             family_satisfaction=mean(family_satisfaction),
                             financial_satisfaction=mean(financial_satisfaction),
                             leisure_satisfaction=mean(leisure_satisfaction),
                             pol_know_all=mean(pol_know_all)
                             
                 ))
  
  # define party supporter 
  ## ==> last vote (vote_le) is set to 1 for all parties, se
  ## set the last vote variable to 0 for all parties besides the specified "party.supporter")    		
  sim.Hcon$vote_le[sim.Hcon$alt!= party.supporter]<-0
  
  
  ## LOW Conflict
  sim.Lcon<-NA
  sim.Lcon<-sim.Hcon
  sim.Lcon$gov_conflict<-4 

  
  ## get predicted probabilities
  pp.Hcon.boot<-NA;   pp.Hcon.boot<-predict(res.boot, sim.Hcon)
  pp.Lcon.boot<-NA;   pp.Lcon.boot<-predict(res.boot, sim.Lcon)

  ## save pp to vote for a given party (here cducsu)
  pp.for.given.party.Hcon[,i]<-pp.Hcon.boot[, "cducsu"]
  pp.for.given.party.Lcon[,i]<-pp.Lcon.boot[, "cducsu"]
  
  cat('\nIteration', i, "from",nsim,'complete, Time:')
  time<-Sys.time()
  print(time[1])	
  flush.console()
  
  
} # close i loop



## get mean and CI from the simulations



ppHcon_pa<-matrix(NA, ncol=3, nrow= 50); colnames(ppHcon_pa)<-c("mean","low","high")
ppLcon_pa<-matrix(NA, ncol=3, nrow= 50); colnames(ppLcon_pa)<-c("mean","low","high")

ppHcon_pa[,"mean"]<-apply(pp.for.given.party.Hcon,1, mean) # rows are econ values, columns are separate simulation
ppHcon_pa[,"low"]<-apply(pp.for.given.party.Hcon,1, quantile,prob=0.025)
ppHcon_pa[,"high"]<-apply(pp.for.given.party.Hcon,1, quantile,prob= 0.975)

ppLcon_pa[,"mean"]<-apply(pp.for.given.party.Lcon,1, mean) # rows are econ values, columns are separate simulation
ppLcon_pa[,"low"]<-apply(pp.for.given.party.Lcon,1, quantile,prob=0.025)
ppLcon_pa[,"high"]<-apply(pp.for.given.party.Lcon,1, quantile,prob= 0.975)







par(mfrow=c(2,2))


plot(y=c(0,1), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="CDU/CSU Vote\n CDU/CSU  Supporters\n High Conflict", cex.main=1) 
lines(x= econ,y= ppHcon[,"mean"], lwd=2, col="black")
lines(x= econ,y=ppHcon[,"high"], lwd=1, col="black", lty=2)
lines(x= econ,y=ppHcon[,"low"], lwd=1, col="black", lty=2)
plot(y=c(0,1), x=c(0,4), type="n", xlab="Economic Decline", ylab="Predicted CDU/CSU Vote", las=1, main="CDU/CSU Vote\n CDU/CSU  Supporters\n Low Conflict", cex.main=1) 

lines(x= econ,y= ppLcon[,"mean"], lwd=2, col="gray")
lines(x= econ,y= ppLcon[,"high"], lwd=1, col="gray", lty=2)
lines(x= econ,y= ppLcon[,"low"], lwd=1, col="gray", lty=2)



plot(y=c(0,1), x=c(0,2.95), type="n", xlab="Policy Diss", ylab="Predicted CDU/CSU Vote", las=1, main="CDU/CSU Vote\n CDU/CSU  Supporters\n High Conflict", cex.main=1) 
lines(x= pa,y= ppHcon_pa[,"mean"], lwd=2, col="black")
lines(x= pa,y=ppHcon_pa[,"high"], lwd=1, col="black", lty=2)
lines(x= pa,y=ppHcon_pa[,"low"], lwd=1, col="black", lty=2)
plot(y=c(0,1), x=c(0, 2.95), type="n", xlab="Policy Diss", ylab="Predicted CDU/CSU Vote", las=1, main="CDU/CSU Vote\n CDU/CSU  Supporters\n Low Conflict", cex.main=1) 

lines(x= pa,y= ppLcon_pa[,"mean"], lwd=2, col="gray")
lines(x= pa,y= ppLcon_pa[,"high"], lwd=1, col="gray", lty=2)
lines(x= pa,y= ppLcon_pa[,"low"], lwd=1, col="gray", lty=2)



